#!/bin/sh
# 
# Photo Image Print System Lite
# Copyright (C) Seiko Epson Corporation 2008.
# 
#  This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
# 

inst_ppd_def=/etc/pipslite/installed-ppd.def
inst_ppd_lst=/etc/pipslite/installed-ppd.lst
commmand=`basename $0`
default_ppd=eklite.ppd
default_option="--default"
INSTALL="install -m 644"
RM="rm -f"


usage () {
    echo "Usage: $commmand {install | deinstall} [$default_option] PPDFile" >&2
    echo "       specify PPDFile with an absolute path" >&2
}

#
# search PPD install directory
#
find_ppd_dir () {
    Installdir=
    Defaultinstalldir=/usr/share/cups/model
# first try to use cups-config, if exist
    if type cups-config >/dev/null 2>&1 ; then
        if cups-config | grep -e "--modeldir" >/dev/null 2>&1 ; then
            Installdir=`cups-config --modeldir`
        else
            Maybe_installdir="`cups-config --datadir`/model"
            if test -d "$Maybe_installdir" ; then
                Installed_ppd=`find "$Maybe_installdir" -type f -a \( -iname "*.ppd" -o -iname "*.ppd.gz" \) -a ! -name "$default_ppd" 2>/dev/null`
                if test "x" != "x$Installed_ppd" ; then
                    Installdir="$Maybe_installdir"
                fi
            fi
        fi
    fi
# try to find PPD dir from package filelist
    if test "x" = "x$Installdir" ; then
        Get_cups_filelist=
        if type dpkg >/dev/null 2>&1 ; then
            if dpkg -p cups >/dev/null 2>&1 ; then
		Get_cups_filelist="dpkg -L cups"
	    elif dpkg -p cupsys >/dev/null 2>&1 ; then
                Get_cups_filelist="dpkg -L cupsys"
            fi
        elif type rpm >/dev/null 2>&1 ; then
            Get_cups_filelist="rpm -ql cups"
        fi
# if it failed to get cups package list, return default install directory (for fail-safe)
        if test "x" = "x$Get_cups_filelist" ; then
            echo "warning: unknown package system" >&2
            echo "$Defaultinstalldir"
            return 0
        fi

        for Cups_default_ppd in epson9.ppd epson24.ppd deskjet.ppd stcolor.ppd stphoto.ppd zebra.ppd ; do
            Cups_default_ppd_dir=`$Get_cups_filelist | grep -i -F $Cups_default_ppd 2>/dev/null`
            if test "x" != "x$Cups_default_ppd_dir" ; then
                case "$Cups_default_ppd_dir" in
                    /usr/share/ppd/*)
                        Installdir=/usr/share/ppd
                        break
                        ;;
                    /opt/share/ppd/*)
                        Installdir=/opt/share/ppd
                        break
                        ;;
                    /usr/share/cups/model/*)
                        Installdir=/usr/share/cups/model
                        break
                        ;;
                    *)
                        ;;
                esac
            fi
        done

        if test "x" = "$Installdir" ; then
            echo "warning: install path not found" >&2
            Installdir="$Defaultinstalldir"
        fi
    fi

    echo "$Installdir"
    return 0
}


#
# main routine
#

if test "x" = "x$1" -o "x" = "x$2" ; then
    usage
    exit 1
fi

if test "x$default_option" = "x$2" -a "x" = "x$3" ; then
    usage
    exit 1
fi

if test 0 -ne `id -u` ; then
    echo "failed to install PPD file: must run as root." >&2
    exit 1
fi

installdir=
err=0
default_flg=false
case "$1" in
    install)
        installdir=`find_ppd_dir`
        if test 0 -ne $? ; then
            exit 1
        fi
        if test "x$default_option" = "x$2" ; then
            default_flg=true
            shift
        fi
        while test "x" != "x$2" ; do
            if echo "$2" | grep -e '^/' >/dev/null 2>&1 ; then
                ppd_full_path="$2"
                if test -r "$ppd_full_path" -a ! -d "$ppd_full_path" ; then
                    if test "x`dirname $ppd_full_path`" != "x$installdir" ; then
                        $INSTALL "$ppd_full_path" "$installdir"
                        if test "xtrue" = "x$default_flg" ; then
                            echo "$installdir/`basename $ppd_full_path`" >> "$inst_ppd_def"
                        else
                            echo "$installdir/`basename $ppd_full_path`" >> "$inst_ppd_lst"
                        fi
                    fi
                else
                    echo "failed to install PPD file: \"$ppd_full_path\" not found" >&2
                    err=1
                fi
            else
                echo "failed to install PPD file: \"$2\" need to be full path" >&2
                err=1
            fi
            shift
        done
        if test 0 -eq $err ; then
            echo "$installdir"
        fi
        ;;
    deinstall)
        inst_ppd_file="$inst_ppd_lst"
        if test "x$default_option" = "x$2" ; then
            default_flg=true
            inst_ppd_file="$inst_ppd_def"
            shift
        fi
        while test "x" != "x$2" ; do
            if test -r "$inst_ppd_file" -a -w "$inst_ppd_file" -a -s "$inst_ppd_file" ; then
                ppd_basename="`basename $2`"
                installed_ppd=`grep -e "$ppd_basename" "$inst_ppd_file"`
                if test "x" != "x$installed_ppd" ; then
                    if test -e "$installed_ppd" ; then
                        if test "x$installed_ppd" != "x$2" ; then
                            $RM "$installed_ppd"
                            mv "$inst_ppd_file" "$inst_ppd_file.tmp"
                            sed -e "\,$installed_ppd,d" "$inst_ppd_file.tmp" > "$inst_ppd_file"
                            $RM "$inst_ppd_file.tmp"
                        fi
                    else
                        echo "failed to uninstall PPD file: \"$installed_ppd\" not found" >&2
                        err=1
                    fi
                else
                    echo "failed to uninstall PPD file: \"$ppd_basename\" not found" >&2
                    err=1
                fi
            fi
            shift
        done
        if test "xtrue" = "x$default_flg" -a "x0" = "x$err" ; then
            $RM "$inst_ppd_file"
        fi
        ;;
    *)
        usage
        exit 1
        ;;
esac

exit $err
